# fritzprofiles
A tool to switch the online time of profiles in the AVM Fritz!Box

Example usage:
```bash
python fritzprofiles.py --user <user> --password <password> --url 192.168.178.1 --get_state --profile Gesperrt --set_state unlimited
```

Modified from https://github.com/flopp/fritz-switch-profiles
